*pysunrunner* is a Python package allowing the user to visualise the output from the *sunRunner3D* model 

*sunRunner3D* is based on the astrophysical MHD code, PLUTO. Although the full code base provides many more features and capabilities than we leverage for *sunRunner3D*, we chose to leave the code untouched, relying only on user-defined boundary conditions to read in data, set the initial conditions, and generate the ICME pulses (i.e., the ad hoc initiation profiles). By so doing, *sunRunner3D* should remain reasonably compatible with any future upgrades to PLUTO and will not require the maintenance of a separate and *ad hoc* version of the code. Thus, in terms of the *pysunrunner* package then, almost everything developed for it should also work with PLUTO output (however, *sunRunner3D* focusses on 3-D spherical solutions). 

Importantly, *pysunrunner* relies on several core Python modules that are distributed with the PLUTO code base, and which were written by Dr. Bhargav Vaidya. For the most part, we have not modified these routines (except for minor changes). One important update, however, was to change several routines that required Python <=3.8. With the updates, *pysunrunner* is fully compatible with 3.9 or greater at the time of writing. However, we recommend 3.12 to run it.
